@@ -1,11 +1,7 @@
-# -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
 from datetime import timedelta
 
 from ..core import WesternCalendar, ChristianMixin
-from ..registry import iso_register
+from ..registry_tools import iso_register
 
 
 @iso_register('PA')
@@ -21,12 +17,12 @@ class Panama(WesternCalendar, ChristianMixin):
         (11, 3, "Independence Day"),
         (11, 5, "Colon Day"),
         (11, 10, "Shout in Villa de los Santos"),
-        (12, 2, "Independence from Spain"),
+        (11, 28, "Independence from Spain"),
         (12, 8, "Mothers' Day"),
     )
 
     def get_variable_days(self, year):
-        days = super(Panama, self).get_variable_days(year)
+        days = super().get_variable_days(year)
         days.append(
             (self.get_ash_wednesday(year) - timedelta(days=1), "Carnival")
         )
