@@ -1,19 +1,23 @@
-# -*- coding: utf-8 -*-
+from .china import China
 from .hong_kong import HongKong
-from .japan import Japan
+from .japan import Japan, JapanBank
 from .malaysia import Malaysia
 from .qatar import Qatar
 from .singapore import Singapore
 from .south_korea import SouthKorea
 from .taiwan import Taiwan
+from .israel import Israel
 
 
 __all__ = (
+    'China',
     'HongKong',
     'Japan',
+    'JapanBank',
     'Malaysia',
     'Qatar',
     'Singapore',
     'SouthKorea',
     'Taiwan',
+    'Israel',
 )
