@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-from workalendar.core import WesternCalendar, ChristianMixin
+from ..core import WesternCalendar, ChristianMixin
 
 
 class EuropeanCentralBank(WesternCalendar, ChristianMixin):
