@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 from datetime import date
-from workalendar.tests import GenericCalendarTest
-from workalendar.africa import (
+from . import GenericCalendarTest
+from ..africa import (
     Algeria,
     Angola,
     Benin,
@@ -10,8 +9,8 @@ from workalendar.africa import (
     SaoTomeAndPrincipe,
     SouthAfrica,
 )
-from workalendar.core import MON, FRI
-from workalendar.exceptions import CalendarError
+from ..core import MON, FRI
+from ..exceptions import CalendarError
 
 
 class AlgeriaTest(GenericCalendarTest):
@@ -455,6 +454,14 @@ class SouthAfricaTest(GenericCalendarTest):
         holidays = self.cal.holidays_set(2016)
         self.assertIn(date(2016, 8, 3), holidays)
 
+    def test_special_2019(self):
+        holidays = self.cal.holidays_set(2019)
+        self.assertIn(date(2019, 5, 8), holidays)  # 2019 National Elections
+
+        # Only in 2019
+        holidays = self.cal.holidays_set(2017)
+        self.assertNotIn(date(2017, 5, 8), holidays)
+
 
 class MadagascarTest(GenericCalendarTest):
     cal_class = Madagascar
